@@ -1,9 +1,9 @@
 {
     'name': "Comunitats Energètiques customizations",
-    'version': '12.0.0.0.12',
+    'version': '12.0.0.0.16',
     'depends': [
         'base_rest_base_structure',
-        'cooperator_website',
+        'l10n_es_cooperator',
         'auth_keycloak',
         'contacts',
         'base_rest',
